@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
@@ -14,9 +15,8 @@ import R from 'ramda'
 import 'moment/min/locales'
 import _ from 'lodash'
 import msgs from '../../nls/platform.properties'
-import { Tag, CodeSnippet } from 'carbon-components-react'
-import CopyToClipboard from 'react-copy-to-clipboard'
 import queryString from 'query-string'
+import { isYAMLEditAvailable } from './search-helper'
 /*
 * UI helpers to help with data transformations
 * */
@@ -35,21 +35,6 @@ export const transform = (resource, key, locale, isSearch) => {
     typeof key.transformFunction === 'function'
   ) {
     return key.transformFunction(resource, locale, key.resourceKey, isSearch)
-  } else if (key.type === 'tag') {
-    var data = key.getData(resource)
-    return data
-      ? data.map((tagText, index) => (
-        <Tag
-            /* eslint-disable-next-line react/no-array-index-key */
-          key={`tag-${index}`}
-          style={{ display: 'inline-block' }}
-          type={'beta'}
-          title={tagText.title}
-          >
-          {tagText.value ? `${tagText.name}:${tagText.value}` : tagText.name}
-        </Tag>
-      ))
-      : '-'
   } else if (key.resourceKey === 'labels' && Array.isArray(value)) {
     return value.length >= 1 ? value.join(', ') : '-'
   } else {
@@ -57,63 +42,6 @@ export const transform = (resource, key, locale, isSearch) => {
   }
 }
 
-export function getLabelsToList(item, locale, labelsKey) {
-  labelsKey = labelsKey || 'labels'
-  const labels = _.get(item, labelsKey)
-  if (!labels || Object.keys(labels).length === 0) {
-    return '-'
-  }
-
-  const showValueAsString = (value, key) => {
-    return (
-      <li key={key + value} style={{ display: 'block' }}>
-        <b>{`${key}`}</b>
-        {` = ${value !== '' ? value : '""'}`}
-      </li>
-    )
-  }
-
-  const showValueAsSnippet = (value, key) => {
-    return (
-      <li key={key + value} style={{ display: 'block' }}>
-        <b>{key}</b>
-        {' ='}
-        <CopyToClipboard text={value}>
-          <CodeSnippet
-            className="removeCopyButton" //Currently used to remove copy button of conde snippet in application detail page  - Adam
-            type="multi"
-            feedback={msgs.get('button.copyButton.feedback', locale)}
-          >
-            {value}
-          </CodeSnippet>
-        </CopyToClipboard>
-      </li>
-    )
-  }
-
-  return (
-    <ul>
-      {_.map(labels, (value, key) => {
-        try {
-          if (typeof value === 'string') {
-            if (!value.trim().startsWith('{')) {
-              // definately a string
-              return showValueAsString(value, key)
-            } else {
-              value = JSON.parse(value)
-            }
-          }
-          // maybe a snippet
-          return showValueAsSnippet(JSON.stringify(value, null, 2), key)
-        } catch (e) {
-          // any errors, show as string
-          return showValueAsString(value, key)
-        }
-      })}
-    </ul>
-  )
-}
-
 const getMoment = (timestamp, locale = '') => {
   const momentObj = moment(
     timestamp,
@@ -159,7 +87,8 @@ export const getClusterCount = ({
   name,
   namespace,
   kind,
-  apigroup = 'apps.open-cluster-management.io'
+  apigroup = 'apps.open-cluster-management.io',
+  clusterNames = []
 }) => {
   const clusterCountString = getClusterCountString(
     locale,
@@ -168,15 +97,24 @@ export const getClusterCount = ({
   )
 
   if (remoteCount) {
-    const searchLink = getSearchLink({
-      properties: {
-        name: name,
-        namespace: namespace,
-        kind,
-        apigroup
-      },
-      showRelated: 'cluster'
-    })
+    const isArgoApp = apigroup.includes('argoproj.io')
+    const searchParams = isArgoApp
+      ? {
+        properties: {
+          name: clusterNames,
+          kind: 'cluster'
+        }
+      }
+      : {
+        properties: {
+          name: name,
+          namespace: namespace,
+          kind,
+          apigroup
+        },
+        showRelated: 'cluster'
+      }
+    const searchLink = getSearchLink(searchParams)
     return (
       <a className="cluster-count-link" href={searchLink}>
         {clusterCountString}
@@ -223,9 +161,13 @@ export const CHANNEL_TYPES = ['git', 'helmrepo', 'namespace', 'objectbucket']
 export const getSearchLink = (params = {}) => {
   const { properties, showRelated } = params
   let textsearch = ''
+
   _.entries(properties).forEach(([key, value]) => {
-    textsearch = `${textsearch}${textsearch ? ' ' : ''}${key}:${value}`
+    textsearch = `${textsearch}${textsearch ? ' ' : ''}${key}:${
+      Array.isArray(value) ? value.join() : value
+    }`
   })
+
   const queryParams = []
   if (textsearch) {
     queryParams.push(
@@ -255,7 +197,11 @@ export const getEditLink = ({
 }
 
 export const createEditLink = item => {
-  return <a href={getEditLink(item)}>{item.name}</a>
+  return isYAMLEditAvailable() ? (
+    <a href={getEditLink(item)}>{item.name}</a>
+  ) : (
+    item.name
+  )
 }
 
 export const getResourceType = (item, locale, key) => {
