@@ -1,13 +1,14 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
-import lodash from 'lodash'
+import _ from 'lodash'
 
 import * as Actions from './index'
 import apolloClient from '../../lib/client/apollo-client'
@@ -15,13 +16,21 @@ import {
   SEARCH_QUERY,
   SEARCH_QUERY_RELATED
 } from '../apollo-client/queries/SearchQueries'
-import { convertStringToQuery } from '../../lib/client/search-helper'
+import {
+  convertStringToQuery,
+  searchError,
+  searchFailure,
+  searchSuccess,
+  shouldTrySearch
+} from '../../lib/client/search-helper'
 import { mapBulkChannels } from '../reducers/data-mappers/mapChannelsBulk'
 import { mapBulkSubscriptions } from '../reducers/data-mappers/mapSubscriptionsBulk'
 import { mapSingleApplication } from '../reducers/data-mappers/mapApplicationsSingle'
 import { RESOURCE_TYPES } from '../../lib/shared/constants'
 import msgs from '../../nls/platform.properties'
 
+const kindApplication = 'kind:application'
+
 export const changeTablePage = ({ page, pageSize }, resourceType) => ({
   type: Actions.TABLE_PAGE_CHANGE,
   page,
@@ -46,7 +55,7 @@ export const receiveResourceSuccess = (response, resourceType) => ({
   type: Actions.RESOURCE_RECEIVE_SUCCESS,
   status: Actions.REQUEST_STATUS.DONE,
   items: response.items,
-  resourceVersion: lodash.get(response, 'metadata.resourceVersion'), //only supported on k8s resoruces
+  resourceVersion: _.get(response, 'metadata.resourceVersion'), //only supported on k8s resoruces
   resourceType
 })
 
@@ -64,6 +73,13 @@ export const receiveResourceNotFound = (err, resourceType) => ({
   resourceType
 })
 
+export const receiveClusterOffline = (err, resourceType) => ({
+  type: Actions.RESOURCE_RECEIVE_CLUSTER_OFFLINE,
+  status: Actions.REQUEST_STATUS.CLUSTER_OFFLINE,
+  err,
+  resourceType
+})
+
 export const requestResource = resourceType => ({
   type: Actions.RESOURCE_REQUEST,
   status: Actions.REQUEST_STATUS.IN_PROGRESS,
@@ -114,91 +130,176 @@ export const getQueryStringForResources = resourcename => {
   case 'HCMSubscription':
     return convertStringToQuery('kind:subscription')
   case 'HCMApplication':
-    return convertStringToQuery('kind:application')
+    return convertStringToQuery(kindApplication)
   case 'HCMPlacementRule':
     return convertStringToQuery('kind:placementrule')
   default:
-    return convertStringToQuery('kind:application')
+    return convertStringToQuery(kindApplication)
   }
 }
 
 export const getQueryStringForResource = (resourcename, name, namespace) => {
-  switch (resourcename) {
-  case 'HCMChannel':
-    return convertStringToQuery(
-      `kind:channel name:${name} namespace:${namespace}`
-    )
-  case 'HCMSubscription':
-    return convertStringToQuery(
-      //get only hub subscriptions
-      `kind:subscription name:${name} namespace:${namespace}`
-    )
-  case 'HCMApplication':
-    return convertStringToQuery(
-      `kind:application name:${name} namespace:${namespace}`
-    )
-  case 'HCMPlacementRule':
-    return convertStringToQuery(
-      `kind:placementrule name:${name} namespace:${namespace}`
-    )
-  default:
-    return convertStringToQuery(
-      `kind:application name:${name} namespace:${namespace}`
-    )
+  let resource = ''
+  const nameForQuery = name ? `name:${name}` : ''
+  const namespaceForQuery = namespace ? ` namespace:${namespace}` : ''
+  if (resourcename) {
+    switch (resourcename) {
+    case 'HCMChannel':
+      resource = 'kind:channel '
+      break
+    case 'HCMSubscription':
+      resource = 'kind:subscription '
+      break
+    case 'HCMApplication':
+      resource = `${kindApplication} `
+      break
+    case 'HCMPlacementRule':
+      resource = 'kind:placementrule '
+      break
+    default:
+      resource = `kind:${resourcename} `
+    }
   }
+  return convertStringToQuery(`${resource}${nameForQuery}${namespaceForQuery}`)
+}
+
+const transformFallbackResult = (resourceType, result) => {
+  if (result && result.data) {
+    switch (resourceType.name) {
+    case RESOURCE_TYPES.QUERY_APPLICATIONS.name:
+      return {
+        data: {
+          applications:
+              result.data.applications &&
+              result.data.applications.map(app => ({
+                name: app.metadata.name,
+                namespace: app.metadata.namespace,
+                created: app.metadata.creationTimestamp,
+                _uid: app.metadata.uid,
+                apiVersion: app.raw.apiVersion,
+                cluster: 'local-cluster',
+                destinationNamespace: _.get(
+                  app,
+                  'raw.spec.destination.namespace'
+                )
+              }))
+        }
+      }
+    case RESOURCE_TYPES.QUERY_SUBSCRIPTIONS.name:
+      return {
+        data: {
+          subscriptions:
+              result.data.subscriptions &&
+              result.data.subscriptions.map(sub => ({
+                name: sub.metadata.name,
+                namespace: sub.metadata.namespace,
+                created: sub.metadata.creationTimestamp,
+                apiVersion: sub.raw.apiVersion,
+                channel: _.get(sub, 'raw.spec.channel'),
+                timeWindow: _.get(sub, 'raw.spec.timewindow.windowtype')
+              }))
+        }
+      }
+    case RESOURCE_TYPES.QUERY_PLACEMENTRULES.name:
+      return {
+        data: {
+          placementRules:
+              result.data.placementrules &&
+              result.data.placementrules.map(pr => ({
+                name: pr.metadata.name,
+                namespace: pr.metadata.namespace,
+                created: pr.metadata.creationTimestamp,
+                apiVersion: pr.raw.apiVersion,
+                replicas: _.get(pr, 'raw.spec.clusterReplicas')
+              }))
+        }
+      }
+    case RESOURCE_TYPES.QUERY_CHANNELS.name:
+      return {
+        data: {
+          channels:
+              result.data.items &&
+              result.data.items.map(ch => ({
+                name: ch.metadata.name,
+                namespace: ch.metadata.namespace,
+                created: ch.metadata.creationTimestamp,
+                apiVersion: ch.raw.apiVersion,
+                type: _.get(ch, 'raw.spec.type'),
+                pathname: _.get(ch, 'raw.spec.pathname')
+              }))
+        }
+      }
+    }
+  }
+  return undefined
 }
 
 const getResourceQuery = resourceType => {
-  let resourceQuery, dataKey
-  switch (resourceType.name) {
-  case 'QueryApplications':
-    resourceQuery = { list: 'ApplicationsList' }
-    dataKey = 'applications'
-    break
-  case 'QuerySubscriptions':
-    resourceQuery = { list: 'SubscriptionsList' }
-    dataKey = 'subscriptions'
-    break
-  case 'QueryPlacementRules':
-    resourceQuery = { list: 'PlacementRulesList' }
-    dataKey = 'placementRules'
-    break
-  case 'QueryChannels':
-    resourceQuery = { list: 'ChannelsList' }
-    dataKey = 'channels'
-    break
-  }
-  if (resourceQuery) {
-    //use Query api to get the data, instead of the generic searchResource
-    return dispatch => {
+  //use Query api to get the data, instead of the generic searchResource
+  return dispatch => {
+    const handleSuccess = result => {
+      return dispatch(
+        receiveResourceSuccess(
+          { items: result.data[resourceType.dataKey] },
+          resourceType
+        )
+      )
+    }
+    const handleFailure = result => {
+      if (result && result.error) {
+        return dispatch(receiveResourceError(result.error, resourceType))
+      } else if (result && result.errors) {
+        return dispatch(receiveResourceError(result.errors[0], resourceType))
+      } else {
+        return dispatch(receiveResourceError('invalid', resourceType))
+      }
+    }
+    const handleError = error => {
+      // catch graph connection error
+      return dispatch(receiveResourceError(error, resourceType))
+    }
+    const fallback = () => {
       apolloClient
-        .get(resourceQuery)
+        .fallback(resourceType)
         .then(result => {
-          if (result.data && result.data[dataKey]) {
-            return dispatch(
-              receiveResourceSuccess(
-                { items: result.data[dataKey] },
-                resourceType
-              )
-            )
+          const transformedResult = transformFallbackResult(
+            resourceType,
+            result
+          )
+          if (transformedResult) {
+            return handleSuccess(transformedResult)
+          } else {
+            return handleFailure(result)
           }
-          if (result.error) {
-            return dispatch(receiveResourceError(result.error, resourceType))
+        })
+        .catch(error => handleError(error))
+    }
+
+    if (!shouldTrySearch() && resourceType.fallback) {
+      fallback()
+    } else {
+      apolloClient
+        .get(resourceType)
+        .then(result => {
+          if (result && result.data && result.data[resourceType.dataKey]) {
+            searchSuccess()
+            return handleSuccess(result)
+          } else if (resourceType.fallback) {
+            searchFailure()
+            return fallback()
+          } else {
+            return handleFailure(result)
           }
-          if (result.errors) {
-            return dispatch(
-              receiveResourceError(result.errors[0], resourceType)
-            )
-          }
-          return dispatch(receiveResourceError('invalid', resourceType))
         })
         .catch(error => {
-          // catch graph connection error
-          return dispatch(receiveResourceError(error, resourceType))
+          if (resourceType.fallback) {
+            searchError()
+            return fallback()
+          } else {
+            return handleError(error)
+          }
         })
     }
-  } else {
-    return null
   }
 }
 
@@ -260,19 +361,47 @@ export const fetchResources = resourceType => {
 export const fetchResource = (resourceType, namespace, name, querySettings) => {
   let query = getQueryStringForResource(resourceType.name, name, namespace)
   if (querySettings) {
-    //query asking for a subset of related kinds and possibly for one subscription only
-    if (querySettings.subscription) {
-      //get related resources only for the selected subscription
+    if (querySettings.isArgoApp) {
+      const argoKinds = querySettings.relatedKinds
+        ? querySettings.relatedKinds.toString()
+        : null
+      //get all resources from the target namespace since they are not linked to the argo application
       query = getQueryStringForResource(
-        RESOURCE_TYPES.HCM_SUBSCRIPTIONS.name,
-        querySettings.subscription,
-        namespace
+        argoKinds,
+        null,
+        querySettings.targetNamespaces.toString()
+      )
+      query.filters.push({
+        property: 'label',
+        values: querySettings.argoAppsLabelNames
+      })
+      //get the cluster for each target namespace and all pods related to this objects only
+      //always ask for related pods, replicaset and replocationcontroller because they are tagged by the app instance
+      // we'll get them if any are linked to the objects returned above
+      query.relatedKinds.push(
+        'cluster',
+        'pod',
+        'replicaset',
+        'replicationcontroller'
       )
-      //ask only for these type of resources
-      query.relatedKinds = querySettings.relatedKinds
     } else {
-      //get related resources for the application, but only this subset
-      query.relatedKinds = querySettings.relatedKinds
+      //query asking for a subset of related kinds and possibly for one subscription only
+      if (querySettings.subscription) {
+        //get related resources only for the selected subscription
+        query = getQueryStringForResource(
+          RESOURCE_TYPES.HCM_SUBSCRIPTIONS.name,
+          querySettings.subscription,
+          namespace
+        )
+        //ask only for these type of resources
+        query.relatedKinds = querySettings.relatedKinds
+      } else {
+        //filter out any argo app with the same name and ns, we are looking here for acm apps
+        query.filters.push({ property: 'apigroup', values: ['!argoproj.io'] })
+
+        //get related resources for the application, but only this subset
+        query.relatedKinds = querySettings.relatedKinds
+      }
     }
   }
   return dispatch => {
@@ -281,15 +410,18 @@ export const fetchResource = (resourceType, namespace, name, querySettings) => {
       .search(SEARCH_QUERY_RELATED, { input: [query] })
       .then(response => {
         if (response.errors) {
+          searchFailure()
           return dispatch(
             receiveResourceError(response.errors[0], resourceType)
           )
         }
-        const searchResult = lodash.get(response, 'data.searchResult', [])
+        const searchResult = _.get(response, 'data.searchResult', [])
         if (
-          searchResult.length === 0 ||
-          lodash.get(searchResult[0], 'items', []).length === 0
+          !querySettings.isArgoApp &&
+          (searchResult.length === 0 ||
+            _.get(searchResult[0], 'items', []).length === 0)
         ) {
+          //ignore this for argo apps, if we got to this point the app exists
           //app not found
           const err = {
             err: msgs.get(
@@ -300,11 +432,12 @@ export const fetchResource = (resourceType, namespace, name, querySettings) => {
           }
           return dispatch(receiveResourceNotFound(err, resourceType))
         }
+        searchSuccess()
         return dispatch(
           receiveResourceSuccess(
             {
               items: mapSingleApplication(
-                lodash.cloneDeep(response.data.searchResult[0])
+                _.cloneDeep(response.data.searchResult[0])
               )
             },
             resourceType
@@ -312,6 +445,7 @@ export const fetchResource = (resourceType, namespace, name, querySettings) => {
         )
       })
       .catch(err => {
+        searchError()
         dispatch(receiveResourceError(err, resourceType))
       })
   }
@@ -328,7 +462,7 @@ export const fetchResourcesInBulk = (resourceType, bulkquery) => {
             receiveResourceError(response.errors[0], resourceType)
           )
         }
-        const dataClone = lodash.cloneDeep(response.data.searchResult)
+        const dataClone = _.cloneDeep(response.data.searchResult)
         let result = false
         if (resourceType.name === 'HCMChannel') {
           result = mapBulkChannels(dataClone)
@@ -503,9 +637,9 @@ export const mutateResourceSuccessFinished = resourceType => ({
 export const clearSuccessFinished = dispatch => {
   [
     RESOURCE_TYPES.QUERY_APPLICATIONS,
-    RESOURCE_TYPES.HCM_CHANNELS,
-    RESOURCE_TYPES.HCM_SUBSCRIPTIONS,
-    RESOURCE_TYPES.HCM_PLACEMENT_RULES
+    RESOURCE_TYPES.QUERY_CHANNELS,
+    RESOURCE_TYPES.QUERY_SUBSCRIPTIONS,
+    RESOURCE_TYPES.QUERY_PLACEMENTRULES
   ].forEach(resourceType => {
     dispatch(mutateResourceSuccessFinished(resourceType))
     dispatch(delResourceSuccessFinished(resourceType))
