@@ -1,20 +1,20 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
-
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import React from 'react'
+import { PageSection } from '@patternfly/react-core'
 import resources from '../../../lib/shared/resources'
 import msgs from '../../../nls/platform.properties'
 import { Query } from 'react-apollo'
 import { getApplication } from '../../../lib/client/queries'
 import PropTypes from 'prop-types'
-import Page from '../common/Page'
 import { withRouter } from 'react-router-dom'
 import { connect } from 'react-redux'
 import {
@@ -30,7 +30,6 @@ import { getApplicationResources } from './transformers/transform-data-to-resour
 import config from '../../../lib/shared/config'
 import _ from 'lodash'
 
-
 // include monaco editor
 import TemplateEditor from 'temptifly'
 import 'temptifly/dist/styles.css'
@@ -39,6 +38,7 @@ import 'monaco-editor/esm/vs/editor/editor.all.js'
 import 'monaco-editor/esm/vs/editor/standalone/browser/quickOpen/quickCommand.js'
 import 'monaco-editor/esm/vs/basic-languages/yaml/yaml.contribution.js'
 import { global_BackgroundColor_dark_100 as editorBackground } from '@patternfly/react-tokens'
+import classNames from 'classnames'
 if (window.monaco) {
   window.monaco.editor.defineTheme('console', {
     base: 'vs-dark',
@@ -48,14 +48,14 @@ if (window.monaco) {
       { token: 'number', foreground: 'ace12e' },
       { token: 'type', foreground: '73bcf7' },
       { token: 'string', foreground: 'f0ab00' },
-      { token: 'keyword', foreground: 'cbc0ff' },
+      { token: 'keyword', foreground: 'cbc0ff' }
     ],
     colors: {
       'editor.background': editorBackground.value,
       'editorGutter.background': '#292e34', // no pf token defined
       'editorLineNumber.activeForeground': '#fff',
-      'editorLineNumber.foreground': '#f0f0f0',
-    },
+      'editorLineNumber.foreground': '#f0f0f0'
+    }
   })
 }
 
@@ -65,14 +65,12 @@ window.MonacoEnvironment = {
   }
 }
 
-
 const Portals = Object.freeze({
   editBtn: 'edit-button-portal-id',
   cancelBtn: 'cancel-button-portal-id',
   createBtn: 'create-button-portal-id'
 })
 
-
 resources(() => {
   require('./style.scss')
 })
@@ -193,48 +191,44 @@ class ApplicationCreationPage extends React.Component {
       // if editing an existing app, grab it first
       const { selectedAppName, selectedAppNamespace } = editApplication
       return (
-        <Page>
-          <Query
-            query={getApplication}
-            variables={{
-              name: selectedAppName,
-              namespace: selectedAppNamespace
-            }}
-          >
-            {result => {
-              const { loading } = result
-              const { data = {} } = result
-              const { application } = data
-              const errored = application ? false : true
-              const error = application ? null : result.error
-              if (!loading && error) {
-                const errorName = result.error.graphQLErrors[0].name
-                  ? result.error.graphQLErrors[0].name
-                  : error.name
-                error.name = errorName
-              }
-              const fetchControl = {
-                resources: getApplicationResources(application),
-                isLoaded: !loading,
-                isFailed: errored,
-                error: error
-              }
-              return this.renderEditor(fetchControl)
-            }}
-          </Query>
-        </Page>
+        <Query
+          query={getApplication}
+          variables={{
+            name: selectedAppName,
+            namespace: selectedAppNamespace
+          }}
+        >
+          {result => {
+            const { loading } = result
+            const { data = {} } = result
+            const { application } = data
+            const errored = application ? false : true
+            const error = application ? null : result.error
+            if (!loading && error) {
+              const errorName = result.error.graphQLErrors[0].name
+                ? result.error.graphQLErrors[0].name
+                : error.name
+              error.name = errorName
+            }
+            const fetchControl = {
+              resources: getApplicationResources(application),
+              isLoaded: !loading,
+              isFailed: errored,
+              error: error
+            }
+            return this.renderEditor(fetchControl)
+          }}
+        </Query>
       )
     }
-    return <Page>{this.renderEditor()}</Page>
+    return this.renderEditor()
   }
 
   renderEditor(fetchControl) {
+    const editApplication = this.getEditApplication()
     const { locale } = this.context
     const { controlData, hasPermissions } = this.state
-    const {
-      mutateStatus,
-      mutateErrorMsgs,
-    } = this.props
+    const { mutateStatus, mutateErrorMsgs } = this.props
     const createControl = {
       hasPermissions,
       createResource: this.handleCreate.bind(this),
@@ -247,17 +241,22 @@ class ApplicationCreationPage extends React.Component {
     }
     return (
       controlData && (
-        <TemplateEditor
-          type={'application'}
-          title={msgs.get('creation.app.yaml', locale)}
-          template={createTemplate}
-          controlData={controlData}
-          monacoEditor={<MonacoEditor />}
-          portals={Portals}
-          fetchControl={fetchControl}
-          createControl={createControl}
-          i18n={i18n}
-        />
+        <PageSection
+          className={classNames({ editApplication })}
+          variant="light"
+        >
+          <TemplateEditor
+            type={'application'}
+            title={msgs.get('creation.app.yaml', locale)}
+            template={createTemplate}
+            controlData={controlData}
+            monacoEditor={<MonacoEditor />}
+            portals={Portals}
+            fetchControl={fetchControl}
+            createControl={createControl}
+            i18n={i18n}
+          />
+        </PageSection>
       )
     )
   }
@@ -267,11 +266,14 @@ class ApplicationCreationPage extends React.Component {
       const { handleCreateApplication, handleUpdateApplication } = this.props
       const editApplication = this.getEditApplication()
       if (editApplication) {
-        handleUpdateApplication(resourceJSON)
+        resourceJSON.createResources.push({
+          deleteLinks: [...resourceJSON.deleteResources]
+        })
+        handleUpdateApplication(resourceJSON.createResources)
       } else {
-        handleCreateApplication(resourceJSON)
+        handleCreateApplication(resourceJSON.createResources)
       }
-      const map = _.keyBy(resourceJSON, 'kind')
+      const map = _.keyBy(resourceJSON.createResources, 'kind')
       this.applicationNamespace = _.get(map, 'Application.metadata.namespace')
       this.applicationName = _.get(map, 'Application.metadata.name')
     }
@@ -284,13 +286,8 @@ class ApplicationCreationPage extends React.Component {
       // Came from the "Create application" button, or "Edit application" table action; go back
       history.goBack()
     } else if (editApplication && location.state && location.state.tabChange) {
-      // Came from changing tabs from "Overview" to "YAML" or clicking "Edit application" button; change tabs back
-      const { selectedAppName, selectedAppNamespace } = editApplication
-      history.replace(
-        `${config.contextPath}/${encodeURIComponent(
-          selectedAppNamespace
-        )}/${encodeURIComponent(selectedAppName)}`
-      )
+      // Came from changing tabs from "Overview" to "Editor"; change tabs back
+      history.replace(location.state.tabChange)
     } else {
       // Otherwise, navigate to applications
       history.push(config.contextPath)
