@@ -1,22 +1,25 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
+
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
-import { VALID_REPOPATH, VALIDATE_URL } from 'temptifly'
+import { VALID_REPOPATH, VALIDATE_URL, getSourcePath } from 'temptifly'
 import placementData from './ControlDataPlacement'
 import prePostTasks from './ControlDataPrePostTasks'
 import {
   getGitBranches,
   loadExistingChannels,
   updateChannelControls,
-  updateGitBranchFolders
+  updateGitBranchFolders,
+  channelSimplified
 } from './utils'
 import _ from 'lodash'
 
@@ -101,6 +104,42 @@ export const updateGitCredentials = (
   return groupControlData
 }
 
+export const updateSubReconcileRate = subReconcileRateControl => {
+  const groupControlData = _.get(subReconcileRateControl, 'groupControlData')
+
+  const gitReconcileOption = groupControlData.find(
+    ({ id }) => id === 'gitReconcileOption'
+  )
+
+  if (subReconcileRateControl.active) {
+    gitReconcileOption.type = 'hidden'
+    gitReconcileOption.active = ''
+  } else {
+    gitReconcileOption.type = 'combobox'
+    gitReconcileOption.active = 'merge'
+  }
+}
+
+export const reverseSubReconcileRate = (control, templateObject) => {
+  const active = _.get(
+    templateObject,
+    getSourcePath(
+      'Subscription[0].metadata.annotations["apps.open-cluster-management.io/reconcile-rate"]'
+    )
+  )
+  if (active) {
+    control.active = true
+
+    const { groupControlData } = control
+    const gitReconcileOption = groupControlData.find(
+      ({ id }) => id === 'gitReconcileOption'
+    )
+    gitReconcileOption.type = 'hidden'
+    gitReconcileOption.active = ''
+  }
+  return control
+}
+
 const githubChannelData = async () => [
   ///////////////////////  github  /////////////////////////////////////
   {
@@ -129,7 +168,17 @@ const githubChannelData = async () => [
     validation: VALIDATE_URL,
     fetchAvailable: loadExistingChannels('git'),
     reverse: 'Channel[0].spec.pathname',
-    onSelect: updateChannelControls
+    onSelect: updateChannelControls,
+    simplified: channelSimplified
+  },
+  {
+    name: 'creation.app.github.secret',
+    tooltip: 'tooltip.creation.app.github.secret',
+    id: 'githubSecret',
+    type: 'hidden',
+    active: '',
+    available: [],
+    disabled: true
   },
   {
     name: 'creation.app.github.user',
@@ -184,6 +233,24 @@ const githubChannelData = async () => [
     ],
     cacheUserValueKey: 'create.app.github.path'
   },
+  {
+    id: 'gitDesiredCommit',
+    type: 'text',
+    name: 'creation.app.github.desiredCommit',
+    tooltip: 'tooltip.creation.app.github.desiredCommit',
+    placeholder: 'app.enter.select.desiredCommit',
+    reverse:
+      'Subscription[0].metadata.annotations["apps.open-cluster-management.io/git-desired-commit"]'
+  },
+  {
+    id: 'gitTag',
+    type: 'text',
+    name: 'creation.app.github.tag',
+    tooltip: 'tooltip.creation.app.github.tag',
+    placeholder: 'app.enter.select.tag',
+    reverse:
+      'Subscription[0].metadata.annotations["apps.open-cluster-management.io/git-tag"]'
+  },
   {
     id: 'gitReconcileOption',
     type: 'combobox',
@@ -194,6 +261,27 @@ const githubChannelData = async () => [
     reverse:
       'Subscription[0].metadata.annotations["apps.open-cluster-management.io/reconcile-option"]'
   },
+  {
+    id: 'gitReconcileRate',
+    type: 'combobox',
+    editing: { disabled: true }, // if editing existing app, disable this field
+    name: 'creation.app.reconcileRate',
+    tooltip: 'tooltip.creation.app.reconcileRate',
+    active: 'medium',
+    available: ['low', 'medium', 'high', 'off'],
+    reverse:
+      'Channel[0].metadata.annotations["apps.open-cluster-management.io/reconcile-rate"]'
+  },
+  {
+    id: 'gitSubReconcileRate',
+    type: 'checkbox',
+    name: 'creation.app.subReconcileRate',
+    tooltip: 'tooltip.creation.app.subReconcileRate',
+    active: false,
+    available: [],
+    onSelect: updateSubReconcileRate,
+    reverse: reverseSubReconcileRate
+  },
   {
     id: 'gitInsecureSkipVerify',
     type: 'checkbox',
