@@ -1,17 +1,22 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- * Copyright (c) 2020 Red Hat, Inc.
+
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
 import msgs from '../../../../nls/platform.properties'
-import { HCMChannelList, HCMSecretsList } from '../../../../lib/client/queries'
+import {
+  HCMAnsibleTower,
+  HCMChannelList
+} from '../../../../lib/client/queries'
 import apolloClient from '../../../../lib/client/apollo-client'
 import { RESOURCE_TYPES } from '../../../../lib/shared/constants'
 import SharedResourceWarning from '../components/SharedResourceWarning'
@@ -30,22 +35,14 @@ export const loadExistingChannels = type => {
   }
 }
 
-export const loadExistingSecrets = () => {
-  const getQueryVariables = (control, globalControl) => {
-    const nsControl = globalControl.find(
-      ({ id: idCtrl }) => idCtrl === 'namespace'
-    )
-    if (nsControl.active) {
-      delete control.exception
-      return { namespace: nsControl.active }
-    } else {
-      control.exception = msgs.get('creation.app.loading.secrets.ns.err')
-      return {}
-    }
+export const loadExistingAnsibleProviders = () => {
+  const ansibleProviderQueryVariables = {
+    label: 'cluster.open-cluster-management.io/type',
+    value: 'ans'
   }
   return {
-    query: HCMSecretsList,
-    variables: getQueryVariables,
+    query: HCMAnsibleTower,
+    variables: ansibleProviderQueryVariables,
     loadingDesc: 'creation.app.loading.secrets',
     setAvailable: setAvailableSecrets.bind(null)
   }
@@ -111,30 +108,31 @@ export const getUniqueChannelName = (channelPath, groupControlData) => {
   return channelName
 }
 
-//check if this is a channel already defined by the current app
-export const isUsingSameChannel = (urlControl, globalControl, channelName) => {
-  let usingSameChannel = false
+// Find first control defining the same channel in the current app
+export const findOriginalChannelControl = (
+  globalControl,
+  channelName,
+  nameControl
+) => {
   const channelsControl = globalControl.find(
     ({ id: idCtrl }) => idCtrl === 'channels'
   )
   if (channelsControl) {
     //get all active channels and see if this channel name was created prior to this; reuse it if found
     const activeDataChannels = _.get(channelsControl, 'active', [])
-    activeDataChannels.forEach(channelInfo => {
+    for (const channelInfo of activeDataChannels) {
       const channelNameInfo = channelInfo.find(
         ({ id: idChannelInfo }) => idChannelInfo === 'channelName'
       )
-      if (
-        channelNameInfo &&
-        _.get(channelNameInfo, 'active', '') === channelName &&
-        _.get(urlControl, 'groupControlData') !== channelInfo
-      ) {
-        usingSameChannel = true
+      if (channelNameInfo) {
+        if (channelNameInfo === nameControl) {
+          return null
+        } else if (_.get(channelNameInfo, 'active', '') === channelName) {
+          return channelInfo
+        }
       }
-    })
+    }
   }
-
-  return usingSameChannel
 }
 
 export const updateChannelControls = (
@@ -163,7 +161,7 @@ export const updateChannelControls = (
     ({ id: idCtrlNSExists }) => idCtrlNSExists === 'channelNamespaceExists'
   )
   let existingChannel = false
-  let usingSameChannel = false
+  let originalChannelControl = null
   // change channel name and namespace to reflect repository path
   if (active) {
     // if existing channel, reuse channel name and namespace
@@ -176,13 +174,13 @@ export const updateChannelControls = (
       const channelName = getUniqueChannelName(active, groupControlData)
       const channelNS = `${channelName}-ns`
 
-      usingSameChannel = isUsingSameChannel(
-        nsControl,
+      originalChannelControl = findOriginalChannelControl(
         globalControl,
-        channelName
+        channelName,
+        nameControl
       )
 
-      if (usingSameChannel) {
+      if (originalChannelControl) {
         // if existing channel, reuse channel name and namespace
         nameControl.active = channelName
         namespaceControl.active = channelNS
@@ -202,37 +200,81 @@ export const updateChannelControls = (
     namespaceControlExists.active = false
   }
 
-  let control
-  // if existing channel, hide user/token controls; show it when using the same channel in the same app
-  const type = !existingChannel || usingSameChannel ? 'text' : 'hidden'
-  const checkboxType =
-    !existingChannel || usingSameChannel ? 'checkbox' : 'hidden'
-  const setType = (cid, isPasswordField, isCheckbox) => {
-    control = groupControlData.find(({ id }) => id === cid)
-    let setCtrlType = isCheckbox ? checkboxType : type
-    if (isPasswordField) {
-      setCtrlType = type === 'hidden' ? type : 'password'
+  // update reconcile rate based on selected channel url
+  // if existing channel or channel already defined in app, make channel reconcile rate readonly
+  // NOTE: existing channels with no reconcile rate set, will use the default medium rate
+  const findReconcileRateControl = control => {
+    return control
+      ? control.find(
+        ({ id }) => id === 'gitReconcileRate' || id === 'helmReconcileRate'
+      )
+      : null
+  }
+
+  const reconcileRate = findReconcileRateControl(groupControlData)
+  const originalReconcileRate = findReconcileRateControl(
+    originalChannelControl
+  )
+
+  let rateValue =
+    _.get(originalReconcileRate || reconcileRate, 'active') || 'medium'
+  if (pathData && pathData.raw) {
+    rateValue = _.get(
+      pathData.raw,
+      'metadata.annotations["apps.open-cluster-management.io/reconcile-rate"]',
+      'medium'
+    )
+  }
+
+  if (reconcileRate) {
+    reconcileRate.active = rateValue
+    reconcileRate.disabled = existingChannel || !!originalChannelControl
+  }
+
+  const secretName = groupControlData.find(
+    ({ id }) =>
+      id === 'githubSecret' || id === 'helmSecret' || id === 'objectstoreSecret'
+  )
+  if (secretName) {
+    if (existingChannel && pathData && pathData.secretRef) {
+      secretName.type = 'text'
+      secretName.active = pathData.secretRef
+    } else {
+      secretName.type = 'hidden'
+      secretName.active = ''
     }
-    _.set(control, 'type', setCtrlType)
-    if (type === 'hidden') {
-      _.set(control, 'active', '')
+  }
+
+  // if existing channel or using same channel, hide user/token controls, region, reconcile rate
+  const showHideOrDisableControl = (cid, defaultType) => {
+    const control = groupControlData.find(({ id }) => id === cid)
+    control.type = existingChannel ? 'hidden' : defaultType
+    if (originalChannelControl) {
+      const originalControl = originalChannelControl.find(c => c.id === cid)
+      if (originalControl) {
+        control.active = originalControl.active
+      }
+      control.disabled = true
+    } else {
+      control.disabled = false
     }
   }
   const { id } = urlControl
   switch (id) {
   case 'githubURL':
-    setType('githubUser')
-    setType('githubAccessId', true)
-    setType('gitInsecureSkipVerify', false, true)
+    showHideOrDisableControl('githubUser', 'text')
+    showHideOrDisableControl('githubAccessId', 'password')
+    showHideOrDisableControl('gitInsecureSkipVerify', 'checkbox')
     break
   case 'objectstoreURL':
-    setType('accessKey')
-    setType('secretKey', true)
+    showHideOrDisableControl('accessKey', 'text')
+    showHideOrDisableControl('secretKey', 'password')
+    showHideOrDisableControl('region', 'text')
     break
   case 'helmURL':
-    setType('helmUser')
-    setType('helmPassword', true)
-    setType('helmInsecureSkipVerify', false, true)
+    showHideOrDisableControl('helmUser', 'text')
+    showHideOrDisableControl('helmPassword', 'password')
+    showHideOrDisableControl('helmInsecureSkipVerify', 'checkbox')
     break
   }
 
@@ -261,18 +303,6 @@ export const updateControlsForNS = (
 
       updateNewRuleControlsData('', control)
     }
-
-    //update ansible secret controls
-    const ansibleSecretName = _.get(control, 'ansibleSecretName')
-    const ansibleTowerHost = _.get(control, 'ansibleTowerHost')
-    const ansibleTowerToken = _.get(control, 'ansibleTowerToken')
-    if (ansibleSecretName && ansibleTowerHost && ansibleTowerToken) {
-      _.set(ansibleSecretName, 'active', '')
-      _.set(ansibleTowerHost, 'active', '')
-      _.set(ansibleTowerToken, 'active', '')
-      _.set(ansibleTowerHost, 'type', 'text')
-      _.set(ansibleTowerToken, 'type', 'text')
-    }
   })
 
   return globalControl
@@ -295,7 +325,14 @@ const retrieveGitDetails = async (
       ({ id }) => id === 'githubAccessId'
     )
 
-    const gitUrl = _.get(gitControl, 'active', '')
+    const selectedChannel = _.get(gitControl, 'availableData', {})[
+      _.get(gitControl, 'active', '')
+    ]
+    // get git repository path from channel object if this is an existing channel, use the combo value otherwise
+    const gitUrl = selectedChannel
+      ? _.get(selectedChannel, 'objectPath', '')
+      : _.get(gitControl, 'active', '')
+
     if (!gitUrl) {
       branchCtrl.active = ''
       branchCtrl.available = []
@@ -307,12 +344,6 @@ const retrieveGitDetails = async (
     if (url.host !== 'github.com') {
       return
     }
-
-    // Check for existing channel
-    const selectedChannel = _.get(
-      _.get(gitControl, 'availableData', {}),
-      gitUrl
-    )
     const queryVariables = {
       gitUrl,
       namespace: _.get(selectedChannel, 'metadata.namespace', ''),
@@ -566,6 +597,15 @@ export const updateNewRuleControlsData = (selectedPR, control) => {
   return control
 }
 
+//return channel path, to show in the combo as a user selection
+export const channelSimplified = (value, control) => {
+  if (!control || !value) {
+    return value
+  }
+  const mappedData = _.get(control, 'availableData', {})[value]
+  return (mappedData && _.get(mappedData, 'objectPath')) || value
+}
+
 export const setAvailableChannelSpecs = (type, control, result) => {
   const { loading } = result
   const { data = {} } = result
@@ -577,17 +617,32 @@ export const setAvailableChannelSpecs = (type, control, result) => {
   if (error) {
     control.isFailed = true
   } else if (items) {
+    const keyFn = item => {
+      return `${_.get(item, 'objectPath', '')} [${_.get(
+        item,
+        'metadata.namespace',
+        'ns'
+      )}/${_.get(item, 'metadata.name', 'name')}]`
+    }
     control.availableData = _.keyBy(
-      items.filter(({ type: p }) => {
-        return p.toLowerCase().startsWith(type)
-      }),
-      'objectPath'
+      items
+        .filter(({ type: p }) => {
+          return p.toLowerCase().startsWith(type)
+        })
+        .filter(({ objectPath: path }) => {
+          return !path
+            .toLowerCase()
+            .includes('multiclusterhub-repo.open-cluster-management')
+        }),
+      keyFn
     )
-    control.available = Object.keys(control.availableData).sort()
+    control.available = _.map(
+      Object.values(control.availableData),
+      keyFn
+    ).sort()
   } else {
     control.isLoading = loading
   }
-
   return control
 }
 
@@ -596,52 +651,26 @@ export const setAvailableSecrets = (control, result) => {
   const { data = {} } = result
   const { secrets } = data
   control.available = []
-  control.availableMap = {}
+  control.hasReplacements = true
+
   control.isLoading = false
   const error = secrets ? null : result.error
   if (error) {
     control.isFailed = true
   } else if (secrets) {
-    control.availableData = _.keyBy(secrets, 'name')
+    control.availableData = _.keyBy(secrets, 'ansibleSecretName')
     control.available = Object.keys(control.availableData).sort()
+    control.availableMap = _.mapValues(control.availableData, replacements => {
+      return {
+        replacements
+      }
+    })
   } else {
     control.isLoading = loading
   }
-
-  updatePrePostControls(control)
-
   return control
 }
 
-export const updatePrePostControls = urlControl => {
-  const groupControlData = _.get(urlControl, 'groupControlData')
-
-  const { active, availableData } = urlControl
-
-  const selectedSecret = availableData && availableData[active]
-
-  const ansibleHost =
-    groupControlData &&
-    groupControlData.find(({ id }) => id === 'ansibleTowerHost')
-  const ansibleToken =
-    groupControlData &&
-    groupControlData.find(({ id }) => id === 'ansibleTowerToken')
-
-  if (!selectedSecret) {
-    //new secret, show host task info
-    _.set(ansibleHost, 'type', 'text')
-    _.set(ansibleToken, 'type', 'password')
-  } else {
-    //existing secret, hide and clean host and token
-    _.set(ansibleHost, 'type', 'hidden')
-    _.set(ansibleToken, 'type', 'hidden')
-    _.set(ansibleHost, 'active', '')
-    _.set(ansibleToken, 'active', '')
-  }
-
-  return urlControl
-}
-
 export const getSharedPlacementRuleWarning = control => (
   <SharedResourceWarning
     resourceType={RESOURCE_TYPES.HCM_PLACEMENT_RULES}
