@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 import jsYaml from 'js-yaml'
 import {
@@ -91,7 +92,7 @@ export const processNodeData = (
       : name
 
   let podsKeyForThisNode = null
-  const clusterName = getClusterName(node.id)
+  const clusterName = getClusterName(node.id, node)
   if (type === 'subscription') {
     //don't use cluster name when grouping subscriptions
     topoResourceMap[name] = node
@@ -129,6 +130,10 @@ export const processNodeData = (
   }
 }
 
+export const evaluateSingleAnd = (operand1, operand2) => {
+  return operand1 && operand2
+}
+
 export const getDiagramElements = (
   topology,
   localStoreKey,
@@ -141,14 +146,13 @@ export const getDiagramElements = (
     loaded,
     reloading,
     willLoadDetails,
-    detailsLoaded,
     detailsReloading
   } = topology
   const topologyReloading = reloading
   const topologyLoadError = status === REQUEST_STATUS.ERROR
   const appLoaded = applicationDetails && applicationDetails.status === 'DONE'
   const specsActiveChannel = 'specs.activeChannel'
-  if (loaded && !topologyLoadError && appLoaded) {
+  if (evaluateSingleAnd(loaded, !topologyLoadError)) {
     // topology from api will have raw k8 objects, pods status
     const { topo_links, topo_nodes } = getTopologyElements(topology)
     // create yaml and what row links to what node
@@ -168,7 +172,9 @@ export const getDiagramElements = (
     topo_nodes.forEach(node => {
       const { id, type } = node
 
-      if (type === 'application' && id.startsWith('application')) {
+      if (
+        evaluateSingleAnd(type === 'application', id.startsWith('application'))
+      ) {
         channelsList = _.get(node, 'specs.channels', [])
         // set default active channel
         const channelListNoAllChannels = channelsList.filter(
@@ -185,8 +191,10 @@ export const getDiagramElements = (
         }
         //active channel not found in the list of channel, remove it
         if (
-          activeChannelInfo &&
-          channelsList.indexOf(activeChannelInfo) === -1
+          evaluateSingleAnd(
+            activeChannelInfo,
+            channelsList.indexOf(activeChannelInfo) === -1
+          )
         ) {
           _.set(node, specsActiveChannel, defaultActiveChannel)
           activeChannelInfo = defaultActiveChannel
@@ -226,22 +234,23 @@ export const getDiagramElements = (
       yaml: yamlStr
     })
 
-    // details are requested separately for faster load
-    // if loaded, we add those details now
-    addDiagramDetails(
-      topology,
-      allResourcesMap,
-      activeChannelInfo,
-      localStoreKey,
-      isClusterGrouped,
-      isHelmRelease,
-      applicationDetails
-    )
-
-    topo_nodes.forEach(node => {
-      computeNodeStatus(node)
-    })
+    if (appLoaded) {
+      // details are requested separately for faster load
+      // if loaded, we add those details now
+      addDiagramDetails(
+        topology,
+        allResourcesMap,
+        activeChannelInfo,
+        localStoreKey,
+        isClusterGrouped,
+        isHelmRelease,
+        applicationDetails
+      )
 
+      topo_nodes.forEach(node => {
+        computeNodeStatus(node)
+      })
+    }
     return {
       clusters: clustersList,
       activeChannel: activeChannelInfo,
@@ -256,7 +265,7 @@ export const getDiagramElements = (
       topologyLoadError,
       topologyReloading,
       willLoadDetails,
-      detailsLoaded,
+      detailsLoaded: appLoaded,
       detailsReloading
     }
   }
@@ -276,7 +285,7 @@ export const getDiagramElements = (
     'fetchFilters.application.channel',
     activeChannelInfo2
   )
-  if (activeChannelInfo2 && loaded) {
+  if (evaluateSingleAnd(activeChannelInfo2, loaded)) {
     //skip this if topology is not loaded ( disable refresh for example)
     const storedElements = getStoredObject(
       `${localStoreKey}-${activeChannelInfo2}`
@@ -301,6 +310,7 @@ export const getDiagramElements = (
   // create application node
   const appId = `application--${iname}`
   nodes2.push({
+    id: appId,
     name: iname,
     namespace: inamespace,
     type: 'application',
@@ -331,6 +341,9 @@ export const addDiagramDetails = (
   applicationDetails
 ) => {
   const { detailsReloading } = topology
+  const lastUpdated = applicationDetails
+    ? _.get(applicationDetails, 'responseTime', null)
+    : null
   // get extra details from topology or from localstore
   let related = []
   if (applicationDetails) {
@@ -353,6 +366,7 @@ export const addDiagramDetails = (
     allResourcesMap,
     isClusterGrouped,
     isHelmRelease,
-    topology
+    topology,
+    lastUpdated
   )
 }
