@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 export const DIAGRAM_SVG_ID = 'topologySvgId'
@@ -14,9 +15,6 @@ export const NODE_RADIUS = 28
 export const NODE_SIZE = 50
 export const MINIMUM_ZOOM_FIT = 0.4 // auto zoom to fit won't drop below this scale
 export const RELATED_OPACITY = 0.3 // opacity of elements related to matched elements
-// export const REFRESH_TIMES = [15, 30, 60, 5 * 60, 30 * 60, 0]
-// export const DEFAULT_REFRESH_TIME = 15
-// export const TOPOLOGY_REFRESH_INTERVAL_COOKIE =
 //   'topotopia-interval-refresh-cookie'
 export const TOPOLOGY_TYPE_FILTER_COOKIE = 'topotopia-type-filter-cookie'
 
@@ -81,6 +79,16 @@ export const ClusterCountIcon = {
   dy: 0
 }
 
+// icon for containing the argo app count
+export const ArgoAppCountIcon = {
+  icon: 'clusterCount',
+  classType: 'argoAppCount',
+  width: 22,
+  height: 18,
+  dx: 26,
+  dy: 0
+}
+
 //if controller contains a pod
 export const PodIcon = {
   icon: 'circle',
