@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 /*
  *
  * Things you should never do inside a reducer:
@@ -22,7 +23,7 @@
 
 import { createResourceReducer, resourceReducerFunction } from './common'
 import { RESOURCE_TYPES } from '../../lib/shared/constants'
-import lodash from 'lodash'
+import _ from 'lodash'
 
 export { user, loggedIn } from './user'
 export { secondaryHeader } from './common'
@@ -36,11 +37,18 @@ export { applicationPageResources } from './application'
 export { AppDeployments } from './reducerAppDeployments'
 export { AppOverview } from './reducerAppOverview'
 
+const keyFields = ['name', 'list']
+
 function predicate(resourceType, action) {
-  if (lodash.isEqual(resourceType, action.resourceType)) {
+  if (
+    _.isEqual(
+      _.pick(resourceType, keyFields),
+      _.pick(action.resourceType, keyFields)
+    )
+  ) {
     return true
   }
-  return lodash.find(lodash.values(resourceType), type => {
+  return _.find(_.values(resourceType), type => {
     if (typeof type === 'string') {
       return type.indexOf(action.resourceType) > -1
     }
@@ -95,4 +103,3 @@ export const userInfoList = createResourceReducer(
 
 export { topology } from './topology'
 export { resourceFilters } from './filter'
-export { refetch } from './refetch'
