@@ -1,9 +1,7 @@
-/*******************************************************************************
- * Licensed Materials - Property of Red Hat, Inc.
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
-const config = JSON.parse(Cypress.env("TEST_CONFIG"));
+const config = Cypress.env("TEST_CONFIG_EXCLUDE_ARGO");
 import { editApplication } from "../../views/application";
 
 describe("Application UI: [P1][Sev1][app-lifecycle-ui] Verify application settings on Editor", () => {
