@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import * as actions from "../../../src-web/actions/common";
 
 const resourceType = {
@@ -37,6 +38,7 @@ const item1 = {
   kind: "application",
   name: "mortgage-app",
   namespace: "default",
+  cluster: "local-cluster",
   dashboard:
     "https://localhost:443/grafana/dashboard/db/mortgage-app-dashboard-via-federated-prometheus?namespace=default",
   clusterCount: 1,
@@ -439,7 +441,7 @@ describe("common actions ", () => {
   it("should return getQueryStringForResource app 1", () => {
     const expectedValue = {
       filters: [
-        { property: "kind", values: ["application"] },
+        { property: "kind", values: ["somename"] },
         { property: "name", values: ["name"] },
         { property: "namespace", values: ["default-ns"] }
       ],
