@@ -1,12 +1,158 @@
 /** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
  ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
+export const ansibleSuccess = {
+  type: "ansiblejob",
+  name: "bigjoblaunch",
+  namespace: "default",
+  id:
+    "member--deployable--member--subscription--default--ansible-tower-job-app-subscription--ansiblejob--bigjoblaunch",
+  specs: {
+    clustersNames: ["local-cluster"],
+    searchClusters: ["local-cluster"],
+    raw: {
+      metadata: {
+        name: "bigjoblaunch",
+        namespace: "default"
+      },
+      spec: {
+        ansibleJobResult: {
+          url: "http://ansible_url/job",
+          status: "successful"
+        },
+        conditions: [
+          {
+            ansibleResult: {},
+            message: "Success",
+            reason: "Successful"
+          }
+        ]
+      }
+    },
+    ansiblejobModel: {
+      "bigjoblaunch-local-cluster": [
+        {
+          label: "tower_job_id=999999999",
+          namespace: "default",
+          cluster: "local-cluster"
+        }
+      ]
+    }
+  }
+};
+export const ansibleError = {
+  type: "ansiblejob",
+  name: "bigjoblaunch",
+  namespace: "default",
+  id:
+    "member--deployable--member--subscription--default--ansible-tower-job-app-subscription--ansiblejob--bigjoblaunch",
+  specs: {
+    clustersNames: ["local-cluster"],
+    searchClusters: ["local-cluster"],
+    raw: {
+      hookType: "pre-hook",
+      metadata: {
+        name: "bigjoblaunch",
+        namespace: "default"
+      }
+    },
+    ansiblejobModel: {
+      "bigjoblaunch-local-cluster": {
+        label: "tower_job_id=999999999"
+      }
+    }
+  }
+};
+export const ansibleError2 = {
+  type: "ansiblejob",
+  name: "bigjoblaunch",
+  namespace: "default",
+  id:
+    "member--deployable--member--subscription--default--ansible-tower-job-app-subscription--ansiblejob--bigjoblaunch",
+  specs: {
+    clustersNames: ["local-cluster"],
+    searchClusters: ["local-cluster"],
+    raw: {
+      hookType: "pre-hook",
+      metadata: {
+        name: "bigjoblaunch",
+        namespace: "default"
+      },
+      spec: {
+        conditions: [
+          {
+            ansibleResult: {
+              failures: 0
+            },
+            message: "Awaiting next reconciliation",
+            reason: "Failed"
+          }
+        ],
+        k8sJob: {
+          message: "some message"
+        }
+      }
+    },
+    ansiblejobModel: {
+      "bigjoblaunch-local-cluster": [
+        {
+          label: "tower_job_id=999999999",
+          cluster: "local-cluster",
+          namespace: "default"
+        }
+      ]
+    }
+  }
+};
+
+export const ansibleErrorAllClusters = {
+  type: "ansiblejob",
+  name: "bigjoblaunch",
+  namespace: "default",
+  id:
+    "member--member--deployable--member--clusters--fxiang-eks,local-cluster,ui-remote--vb-ansible-2--prehook-test-1-c0b22a--ansiblejob--prehook-test-1-c0b22a",
+  specs: {
+    clustersNames: ["local-cluster", "ui-remote", "fxiang-eks"],
+    searchClusters: ["local-cluster"],
+    raw: {
+      hookType: "pre-hook",
+      metadata: {
+        name: "bigjoblaunch",
+        namespace: "default"
+      },
+      spec: {
+        conditions: [
+          {
+            ansibleResult: {
+              failures: 0
+            },
+            message: "Awaiting next reconciliation",
+            reason: "Failed"
+          }
+        ],
+        k8sJob: {
+          message: "some message"
+        }
+      }
+    },
+    ansiblejobModel: {
+      "bigjoblaunch-local-cluster": [
+        {
+          label: "tower_job_id=999999999",
+          cluster: "local-cluster",
+          namespace: "default"
+        }
+      ]
+    }
+  }
+};
 
 export const serverProps = {
   context: {
@@ -40,6 +186,7 @@ export const appNormalizedItems = {
       _uid: "local-cluster/5cd1d4c7-52aa-11ea-bf05-00000a102d26",
       name: "mortgage-app",
       namespace: "default",
+      cluster: "local-cluster",
       dashboard:
         "https://localhost:443/grafana/dashboard/db/mortgage-app-dashboard-via-federated-prometheus?namespace=default",
       clusterCount: { remoteCount: 1 },
@@ -109,12 +256,14 @@ export const QueryApplicationList = {
   sortColumn: 1,
   mutateStatus: "DONE",
   deleteStatus: "DONE",
+  responseTime: 1530518207007 - 15000,
   deleteMsg: "app123",
   items: [
     {
       _uid: "local-cluster/96218695-3798-4dac-b3d3-179fb86b6715",
       name: "mortgage-app",
       namespace: "default",
+      cluster: "local-cluster",
       dashboard:
         "https://localhost:443/grafana/dashboard/db/mortgage-app-dashboard-via-federated-prometheus?namespace=default",
       clusterCount: { remoteCount: 1 },
@@ -325,6 +474,7 @@ export const QueryChannelList = {
   sortColumn: 1,
   mutateStatus: "DONE",
   deleteStatus: "DONE",
+  responseTime: 1530518207007 - 15000,
   deleteMsg: "app123",
   items: [
     {
@@ -634,7 +784,7 @@ export const HCMApplicationList = {
               status: "Failed",
               timeWindow: "none",
               _clusterNamespace: "kcormier-cluster",
-              _gitbranch: "master",
+              _gitbranch: "main",
               _gitpath: "mortgage",
               _hostingDeployable:
                 "kcormier-cluster/mortgage-app-subscription-deployable-w2qpd",
@@ -657,7 +807,7 @@ export const HCMApplicationList = {
                 "/apis/apps.open-cluster-management.io/v1/namespaces/default/subscriptions/mortgage-app-subscription",
               status: "Propagated",
               timeWindow: "active",
-              _gitbranch: "master",
+              _gitbranch: "main",
               _gitpath: "mortgage",
               _gitcommit: "0660bd66c02d09a4c8813d3ae2e711fc98b6426b",
               _hubClusterResource: "true",
@@ -766,6 +916,7 @@ export const HCMApplicationList = {
   resourceVersion: undefined,
   search: "",
   sortDirection: "asc",
+  responseTime: 1530518207007 - 15000,
   status: "DONE"
 };
 
@@ -1163,7 +1314,7 @@ export const topologyNoChannel = {
               name: "mortgage-app-subscription",
               namespace: "default",
               annotations: {
-                "apps.open-cluster-management.io/git-branch": "master",
+                "apps.open-cluster-management.io/git-branch": "main",
                 "apps.open-cluster-management.io/git-path": "mortgage"
               }
             },
@@ -1241,7 +1392,7 @@ export const topologyNoChannel = {
           kind: "Subscription",
           metadata: {
             annotations: {
-              "apps.open-cluster-management.io/github-branch": "master",
+              "apps.open-cluster-management.io/github-branch": "main",
               "apps.open-cluster-management.io/github-path": "mortgage"
             },
             creationTimestamp: "2018-08-13T19:23:01Z",
@@ -1566,8 +1717,10 @@ export const topology = {
               name: "mortgage-app-subscription",
               namespace: "default",
               annotations: {
-                "apps.open-cluster-management.io/git-branch": "master",
-                "apps.open-cluster-management.io/git-path": "mortgage"
+                "apps.open-cluster-management.io/git-branch": "main",
+                "apps.open-cluster-management.io/git-path": "mortgage",
+                "apps.open-cluster-management.io/manual-refresh-time":
+                  "2020-09-13T18:25:01Z"
               }
             },
             spec: {
@@ -1644,7 +1797,7 @@ export const topology = {
           kind: "Subscription",
           metadata: {
             annotations: {
-              "apps.open-cluster-management.io/github-branch": "master",
+              "apps.open-cluster-management.io/github-branch": "main",
               "apps.open-cluster-management.io/github-path": "mortgage"
             },
             creationTimestamp: "2018-08-13T19:23:01Z",
@@ -2084,6 +2237,9 @@ export const reduxStoreAllAppsPipeline = {
   AppDeployments: {
     displaySubscriptionModal: false
   },
+  location: {
+    pathname: "/multicloud/applications/"
+  },
   resourceFilters: {
     filters: {},
     selectedFilters: {}
