@@ -1,12 +1,13 @@
 /** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
  ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 export const sidePanelPolicies = [
   {
     name: "cluster1",
@@ -2098,15 +2099,9 @@ export const resourceModalLabelsDummy = {
 };
 
 export const resourceModalLabels = {
-  primaryBtn: "modal.remove-hcmapplication.heading",
-  label: "modal.remove-hcmapplication.label",
-  heading: "modal.remove-hcmapplication.heading"
-};
-
-export const resourceModalReduxLabels = {
-  primaryBtn: "modal.edit-hcmapplication.heading",
-  label: "modal.edit-hcmapplication.label",
-  heading: "modal.edit-hcmapplication.heading"
+  primaryBtn: "modal.remove-queryapplications.heading",
+  label: "modal.remove-queryapplications.label",
+  heading: "modal.remove-queryapplications.heading"
 };
 
 export const availableFilters = {
