@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 "use strict";
 jest.mock("../../../../lib/client/apollo-client", () => ({
   getClient: jest.fn(() => {
@@ -87,7 +88,10 @@ import { BrowserRouter } from "react-router-dom";
 describe("RemoveResourceModal test", () => {
   const handleModalClose = jest.fn();
   const handleModalSubmit = jest.fn();
-  const resourceType = { name: "HCMApplication", list: "HCMApplicationList" };
+  const resourceType = {
+    name: "QueryApplications",
+    list: "QueryApplicationList"
+  };
   const preloadedState = window.__PRELOADED_STATE__;
   const composeEnhancers =
     window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || compose;
@@ -133,7 +137,7 @@ describe("RemoveResourceModal test", () => {
       .simulate("click");
 
     component
-      .find(".pf-m-secondary")
+      .find(".pf-m-link")
       .at(0)
       .simulate("click");
 
