@@ -76,6 +76,14 @@ var useMultiLineBackgrounds = function (props) {
 };
 
 var getStyles = function (style, props) {
+  if (props.disableInlineStyles) {
+    var baseStyles = Helpers.evaluateStyle(style, props);
+    return {
+      // Font size is necessary to calculate the y position of the label
+      fontSize: getFontSize(baseStyles)
+    };
+  }
+
   var getSingleStyle = function (s) {
     s = s ? _defaults({}, s, defaultStyles) : defaultStyles;
     var baseStyles = Helpers.evaluateStyle(s, props);
