@@ -1,4 +1,4 @@
-var _Object$create = require("../core-js/object/create");
+var _Object$create = require("@babel/runtime-corejs3/core-js/object/create");
 
 var setPrototypeOf = require("./setPrototypeOf");
 
