@@ -2,7 +2,6 @@ import * as React from 'react';
 import {
   AnimatePropTypeInterface,
   CategoryPropType,
-  ColorScalePropType,
   Data,
   DataGetterPropType,
   EventCallbackInterface,
@@ -68,6 +67,7 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * The animate prop should also be used to specify enter and exit
    * transition configurations with the `onExit` and `onEnter` namespaces respectively.
    *
+   * @propType boolean | object
    * @example
    * {duration: 500, onExit: () => {}, onEnter: {duration: 500, before: () => ({y: 0})})}
    */
@@ -92,11 +92,16 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * these arrays of values specified for x and y. If this prop is not set,
    * categorical data will be plotted in the order it was given in the data array
    *
+   * @propType string[] | { x: string[], y: string[] }
    * @example ["dogs", "cats", "mice"]
    */
   categories?: CategoryPropType;
   /**
    * The utilization donut chart to render with the threshold donut chart
+   *
+   * Note: This prop should not be set manually.
+   *
+   * @hide
    */
   children?: React.ReactElement<any>;
   /**
@@ -106,7 +111,7 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * values from this color scale to the pie slices unless colors are explicitly provided in the
    * data object
    */
-  colorScale?: ColorScalePropType;
+  colorScale?: string[];
   /**
    * The constrainToVisibleArea prop determines whether to coerce tooltips so that they fit within the visible area of
    * the chart. When this prop is set to true, tooltip pointers will still point to the correct data point, but the
@@ -131,6 +136,8 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
   containerComponent?: React.ReactElement<any>;
   /**
    * Set the cornerRadius for every dataComponent (Slice by default) within ChartDonutThreshold
+   *
+   * @propType number | Function
    */
   cornerRadius?: SliceNumberOrCallback<SliceProps, 'cornerRadius'>;
   /**
@@ -176,6 +183,8 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
   /**
    * Similar to data accessor props `x` and `y`, this prop may be used to functionally
    * assign eventKeys to data
+   *
+   * @propType number | string | Function
    */
   eventKey?: StringOrNumberOrCallback;
   /**
@@ -193,6 +202,7 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * element (i.e. a single bar), and the object returned from the mutation function
    * will override the props of the selected element via object assignment.
    *
+   * @propType object[]
    * @example
    * events={[
    *   {
@@ -222,6 +232,8 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
   events?: EventPropTypeInterface<'data' | 'labels' | 'parent', StringOrNumberOrCallback | string[] | number[]>[];
   /**
    * ChartDonutThreshold uses the standard externalEventMutations prop.
+   *
+   * @propType object[]
    */
   externalEventMutations?: EventCallbackInterface<string | string[], StringOrNumberOrList>[];
   /**
@@ -242,6 +254,8 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
   /**
    * When creating a donut chart, this prop determines the number of pixels between
    * the center of the chart and the inner edge.
+   *
+   * @propType number | Function
    */
   innerRadius?: NumberOrCallback;
   /**
@@ -251,6 +265,8 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
   /**
    * The labelRadius prop defines the radius of the arc that will be used for positioning each slice label.
    * If this prop is not set, the label radius will default to the radius of the pie + label padding.
+   *
+   * @propType number | Function
    */
   labelRadius?: number | ((props: SliceProps) => number);
   /**
@@ -270,12 +286,16 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
   /**
    * Victory components will pass an origin prop is to define the center point in svg coordinates for polar charts.
    *
-   * **This prop should not be set manually.**
+   * Note: It will not typically be necessary to set an origin prop manually
+   *
+   * @propType { x: number, y: number }
    */
   origin?: OriginType;
   /**
    * The padAngle prop determines the amount of separation between adjacent data slices
    * in number of degrees
+   *
+   * @propType number | Function
    */
   padAngle?: NumberOrCallback;
   /**
@@ -283,17 +303,23 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * the edge of the chart and any rendered child components. This prop can be given
    * as a number or as an object with padding specified for top, bottom, left
    * and right.
+   *
+   * @propType number | { top: number, bottom: number, left: number, right: number }
    */
   padding?: PaddingProps;
   /**
    * Specifies the radius of the chart. If this property is not provided it is computed
    * from width, height, and padding props
+   *
+   * @propType number | Function
    */
   radius?: NumberOrCallback;
   /**
    * The sharedEvents prop is used internally to coordinate events between components.
    *
-   * **This prop should not be set manually.**
+   * Note: This prop should not be set manually.
+   *
+   * @hide
    */
   sharedEvents?: { events: any[]; getEventState: Function };
   /**
@@ -304,10 +330,14 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * Use the sortKey prop to indicate how data should be sorted. This prop
    * is given directly to the lodash sortBy function to be executed on the
    * final dataset.
+   *
+   * @propType number | string | Function | string[]
    */
   sortKey?: DataGetterPropType;
   /**
    * The sortOrder prop specifies whether sorted data should be returned in 'ascending' or 'descending' order.
+   *
+   * @propType string
    */
   sortOrder?: SortOrderPropType;
   /**
@@ -326,6 +356,7 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * so valid Radium style objects should work for this prop. Height, width, and
    * padding should be specified via the height, width, and padding props.
    *
+   * @propType { parent: object, data: object, labels: object }
    * @example {data: {stroke: "black"}, label: {fontSize: 10}}
    */
   style?: VictoryStyleInterface;
@@ -343,6 +374,8 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * When using ChartDonutThreshold as a solo component, implement the theme directly on
    * ChartDonutThreshold. If you are wrapping ChartDonutThreshold in ChartChart or ChartGroup,
    * please call the theme on the outermost wrapper component instead.
+   *
+   * @propType object
    */
   theme?: ChartThemeDefinition;
   /**
@@ -383,6 +416,7 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'x', 'x.value.nested.1.thing', 'x[2].also.nested', null, d => Math.sin(d)
    */
   x?: DataGetterPropType;
@@ -395,6 +429,7 @@ export interface ChartDonutThresholdProps extends ChartDonutProps {
    * it will be used as a nested object property path (for details see Lodash docs for _.get).
    * If `null` or `undefined`, the data value will be used as is (identity function/pass-through).
    *
+   * @propType number | string | Function | string[]
    * @example 0, 'y', 'y.value.nested.1.thing', 'y[2].also.nested', null, d => Math.sin(d)
    */
   y?: DataGetterPropType;
