@@ -24,6 +24,8 @@ export interface CheckboxProps
   'aria-label'?: string;
   /** Description text of the checkbox. */
   description?: React.ReactNode;
+  /** Body text of the checkbox */
+  body?: React.ReactNode;
 }
 
 // tslint:disable-next-line:no-empty
@@ -59,8 +61,13 @@ export class Checkbox extends React.Component<CheckboxProps> {
       checked,
       defaultChecked,
       description,
+      body,
       ...props
     } = this.props;
+    if (!props.id) {
+      // eslint-disable-next-line no-console
+      console.error('Checkbox:', 'id is required to make input accessible');
+    }
     const checkedProps: { checked?: boolean; defaultChecked?: boolean } = {};
     if ([true, false].includes(checked) || isChecked === true) {
       checkedProps.checked = checked || isChecked;
@@ -74,7 +81,7 @@ export class Checkbox extends React.Component<CheckboxProps> {
 
     checkedProps.checked = checkedProps.checked === null ? false : checkedProps.checked;
     return (
-      <div className={css(styles.check, className)}>
+      <div className={css(styles.check, !label && styles.modifiers.standalone, className)}>
         <input
           {...props}
           className={css(styles.checkInput)}
@@ -91,7 +98,8 @@ export class Checkbox extends React.Component<CheckboxProps> {
             {label}
           </label>
         )}
-        {description && <div className={css(styles.checkDescription)}>{description}</div>}
+        {description && <span className={css(styles.checkDescription)}>{description}</span>}
+        {body && <span className={css(styles.checkBody)}>{body}</span>}
       </div>
     );
   }
